@@ -19,7 +19,7 @@
 
 import sys
 
-def get_buildscript(config, module_list):
+def get_buildscript(config, module_list=None):
     modname = 'jhbuild.frontends.%s' % config.buildscript
     __import__(modname)
     BuildScript = sys.modules[modname].BUILD_SCRIPT
